@@ -8,7 +8,7 @@ import os
 
 # S3 Object
 class s3_connect(object):
-    
+
     def __init__(self, config_file, section):
         '''
         provide config file with options:
@@ -16,7 +16,7 @@ class s3_connect(object):
             aws_secret_access_key
             default_bucket
         section = config section for s3
-        
+
         example:
         [s3]
             aws_access_key_id=<key_id>
@@ -24,7 +24,7 @@ class s3_connect(object):
             default_bucket=<bucket>
 
         Basic Usage:
-        
+
         >>> from db_utils.s3_connect import s3_connect
         >>>
         >>> s3 = s3_connect('.databases.conf', 's3')
@@ -32,7 +32,7 @@ class s3_connect(object):
 
         '''
         creds = configparser.ConfigParser()
-        creds.read(config_file) 
+        creds.read(config_file)
         self.DEFAULT_BUCKET=creds.get(section, 'default_bucket')
 
         self.conn = boto3.resource(
@@ -41,7 +41,7 @@ class s3_connect(object):
             aws_secret_access_key=creds.get(section, 'aws_secret_access_key'),
         )
 
-    
+
     def list_keys(self, bucket=None, prefix=None):
         '''
         bucket = defaults_bucket in config file
@@ -57,7 +57,7 @@ class s3_connect(object):
 
         if prefix:
             return [key.key for key in bk.objects.filter(Prefix=prefix)]
-        else:        
+        else:
             return [key.key for key in bk.objects.all()]
 
 
@@ -69,7 +69,7 @@ class s3_connect(object):
         '''
         if bucket == None:
             bucket = self.DEFAULT_BUCKET
-        
+
         self.conn.Bucket(bucket).upload_file(file_location, key)
         return '{0}/{1}'.format(bucket, key)
 
@@ -77,40 +77,46 @@ class s3_connect(object):
     def upload_model(self, model, file_location, model_type, bucket=None, pkl_model_type='', append_ts=False, suffix='csv'):
         '''
         bucket = optional, defaults to 'default_bucket' section in config file
-        model = ('complaints_first_send', 
-                'complaints_next_send', 
+        model = ('complaints_first_send',
+                'complaints_next_send',
                 'offer_recommender',
                 'offer_recommender_v2',
                 'offer_recommender_v2_1',
+                'offer_recommender_v2_2',
                 'complaint_model_v2_0',
-                'reactivation_model_v2_0')
-        
+                'complaint_model_v2_1',
+                'reactivation_model_v2_0',
+                'reactivation_model_v2_1')
+
         file_location = path to file
-        
+
         model_type = (input | output | pickled_model)
         pkl_model_type = (scaler |random_forest | collaborative_filter)
-        
+
         append_ts = Boolean appends SQL friendly timestamp col to CSV file
                     YYYY-MM-DD HH:MM:SS
-        
+
         uploads to s3://<bucket>/models/<model>/(input | output)/<year>/<month>/<day>_<type><timestamp>.csv
         returns dict {'bucket': <bucket>, 'key': <key>}
-        
+
         '''
         valid_models = (
-            'complaints_first_send', 
-            'complaints_next_send', 
+            'complaints_first_send',
+            'complaints_next_send',
             'offer_recommender',
             'offer_recommender_v2',
             'offer_recommender_v2_1',
+            'offer_recommender_v2_2',
             'complaint_model_v2_0',
-            'reactivation_model_v2_0'
+            'complaint_model_v2_1',
+            'reactivation_model_v2_0',
+            'reactivation_model_v2_1'
             )
 
         types = ('input', 'output', 'pickled_model')
 
-        pkl_model_types = ('scaler', 'random_forest', 'collaborative_filter', 'lstm')
-        
+        pkl_model_types = ('scaler', 'random_forest', 'collaborative_filter', 'lstm', 'deep')
+
         if model not in valid_models:
             raise TypeError('model must be {0}'.format(valid_models))
 
@@ -125,7 +131,7 @@ class s3_connect(object):
 
         if bucket == None:
             bucket = self.DEFAULT_BUCKET
-        
+
         time = datetime.now()
         params = {
             "year": time.strftime('%Y'),
@@ -137,7 +143,7 @@ class s3_connect(object):
             "pkl_model_type": pkl_model_type,
             "suffix": suffix
         }
-        
+
         if append_ts == True:
             timestamp = '{year}-{month}-{day} {time}'.format(**params)
             f_out_name = file_location.split('.')[0] + '_appended.txt'
@@ -150,11 +156,11 @@ class s3_connect(object):
             os.remove(file_location)
             os.rename(f_out_name, file_location)
             print('timestamps appended to ' + file_location)
-        
-        
+
+
         key = 'models/{model}/{model_type}/{year}/{month}/{pkl_model_type}{day}_{time}.{suffix}'.format(**params)
         self.upload_file(file_location, key, bucket=bucket)
-        
+
         return {'bucket': bucket, 'key': key, 'params': params}
 
 
@@ -166,7 +172,7 @@ class s3_connect(object):
         '''
         if bucket == None:
             bucket = self.DEFAULT_BUCKET
-        
+
         copy_source = {
             'Bucket': bucket,
             'Key': copy_key
@@ -185,7 +191,7 @@ class s3_connect(object):
             bucket = self.DEFAULT_BUCKET
         if dest_file == None:
             dest_file = key.split('/')[-1]
-            
+
         bucket = self.conn.Bucket(bucket)
         bucket.download_file(key, dest_file)
 
@@ -200,4 +206,4 @@ class s3_connect(object):
         if bucket == None:
             bucket = self.DEFAULT_BUCKET
 
-        return self.conn.Object(bucket, key).delete()
\ No newline at end of file
+        return self.conn.Object(bucket, key).delete()
